@@ -1,7 +1,7 @@
 package HTML::TreeBuilder::LibXML;
 use strict;
 use warnings;
-our $VERSION = '0.01_03';
+our $VERSION = '0.02';
 use Carp ();
 use base 'HTML::TreeBuilder::LibXML::Node';
 use XML::LibXML;
@@ -18,6 +18,7 @@ sub parse {
     $parser->recover_silently(1);
     $parser->keep_blanks(0);
     $parser->expand_entities(1);
+    $parser->no_network(1);
     my $doc = $parser->parse_html_string($html);
     $self->{node} = $doc->documentElement;
 }
@@ -74,6 +75,12 @@ http://d.hatena.ne.jp/woremacx/20080202/1201927162
 
 Tokuhiro Matsuno E<lt>tokuhirom  slkjfd gmail.comE<gt>
 
+=head1 THANKS TO
+
+Tatsuhiko Miyagawa
+
+id:dailyflower
+
 =head1 SEE ALSO
 
 L<HTML::TreeBuilder>, L<HTML::TreeBuilder::XPath>
